==> client-sdk-react-1.13.0.tgz: package/src/examples/Meeting/Meeting.tsx <==
import React, { useState } from 'react'
import ReactDOM from 'react-dom'
import { RoomInfo } from '@zocks-communications/client-sdk-js'
import { useLeaveOnUnload, useNewMessagesFrom, useZocksActions, useZocksSession } from '../../store'
import {
  CombinedChat,
  JoinPage,
  Participants,
  RoomControls,
  ViewSwitcher,
  OnlineParticipantsList,
  ChatInputElementProps,
  CustomizableChatInput,
  RecipientSelectorElementProps,
  RecipientSelector,
} from '../../components'
import './Meeting.scss'

const ChatInputWithoutEmojiSelector: React.FC<ChatInputElementProps> = (props) => {
  return (
    <CustomizableChatInput
      {...props}
      emojiSelectorElement={() => null}
      recipientSelectorElement={RecipientSelectorWithSenderClear}
    />
  )
}

const RecipientSelectorWithSenderClear: React.FC<RecipientSelectorElementProps> = (props) => {
  const { clearMessageFrom } = useNewMessagesFrom()

  const onRecipientSelected = (recipientId: string) => {
    clearMessageFrom(recipientId)
    props.onRecipientSelected(recipientId)
  }
  return <RecipientSelector {...props} onRecipientSelected={onRecipientSelected} />
}

export const Meeting = () => {
  const { sessionActions, localMediaActions, chatActions } = useZocksActions({
    accountId: '',
  })
  const { sessionId, localParticipantIsConnected } = useZocksSession()
  useLeaveOnUnload(sessionActions.leave)

  const [showParticipantsList, setShowParticipantsList] = useState(false)
  const [showChat, setShowChat] = useState(false)
  const [newRoom, setNewRoom] = useState<RoomInfo | null>(null)

  return (
    <div className='meeting'>
      <h1>Example</h1>
      <div>{'Session id: ' + sessionId}</div>
      <div>{'Connected: ' + localParticipantIsConnected}</div>
      {!localParticipantIsConnected ? (
        <>
          <JoinPage
            createRoomAction={sessionActions.createRoom}
            joinAction={sessionActions.join}
            onNewRoomCreated={(roomInfo) => setNewRoom(roomInfo)}
          />
          {newRoom && <div>{`New room created: ${JSON.stringify(newRoom)}`}</div>}
        </>
      ) : (
        <>
          <div className='meeting__participants-list' id='participants-list-root' />
          <div className='meeting__chat' id='chat-root' />
          {showParticipantsList &&
            ReactDOM.createPortal(
              <OnlineParticipantsList dismiss={() => setShowParticipantsList(false)} />,
              document.getElementById('participants-list-root')!
            )}
          {showChat &&
            ReactDOM.createPortal(
              <CombinedChat
                chatActions={chatActions}
                dismiss={() => setShowChat(false)}
                chatInputElement={ChatInputWithoutEmojiSelector}
              />,
              document.getElementById('chat-root')!
            )}
          <div className='room-controls'>
            <RoomControls mediaActions={localMediaActions} leaveAction={sessionActions.leave} />
          </div>
          <ViewSwitcher />
          <Participants speakerPageSize={4} />
          <div className='meeting__participants-list-button-container'>
            <button
              className='meeting__participants-list-button'
              disabled={showParticipantsList}
              onClick={() => setShowParticipantsList(true)}
            >
              Show Participants
            </button>
          </div>
          <div className='meeting__chat-button-container'>
            <button className='meeting__chat-button' disabled={showChat} onClick={() => setShowChat(true)}>
              Show Chat
            </button>
          </div>
        </>
      )}
    </div>
  )
}

==> client-sdk-react-1.15.0.tgz: package/src/examples/Meeting/Meeting.tsx <==
import React, { useState } from 'react'
import ReactDOM from 'react-dom'
import { RoomInfo } from '@zocks-communications/client-sdk-js'
import { useLeaveOnUnload, useNewMessagesFrom, useZocksActions, useZocksSession } from '../../store'
import {
  CombinedChat,
  JoinPage,
  Participants,
  RoomControls,
  ViewSwitcher,
  OnlineParticipantsList,
  ChatInputElementProps,
  CustomizableChatInput,
  RecipientSelectorElementProps,
  RecipientSelector,
} from '../../components'
import './Meeting.scss'

const ChatInputWithoutEmojiSelector: React.FC<ChatInputElementProps> = (props) => {
  return (
    <CustomizableChatInput
      {...props}
      emojiSelectorElement={() => null}
      recipientSelectorElement={RecipientSelectorWithSenderClear}
    />
  )
}

const RecipientSelectorWithSenderClear: React.FC<RecipientSelectorElementProps> = (props) => {
  const { clearMessageFrom } = useNewMessagesFrom()

  const onRecipientSelected = (recipientId: string) => {
    clearMessageFrom(recipientId)
    props.onRecipientSelected(recipientId)
  }
  return <RecipientSelector {...props} onRecipientSelected={onRecipientSelected} />
}

export const Meeting = () => {
  const { sessionActions, localMediaActions, chatActions } = useZocksActions({
    apiBaseUrl: 'https://api.zocks.io/v1',
    accountId: 'db8mt16gxt8ueddw',
  })
  const { roomId, localParticipantIsConnected } = useZocksSession()
  useLeaveOnUnload(sessionActions.leave)

  const [showParticipantsList, setShowParticipantsList] = useState(false)
  const [showChat, setShowChat] = useState(false)
  const [newRoom, setNewRoom] = useState<RoomInfo | null>(null)

  return (
    <div className='meeting'>
      <h1>Example</h1>
      <div>{'Room id: ' + roomId}</div>
      <div>{'Connected: ' + localParticipantIsConnected}</div>
      {!localParticipantIsConnected ? (
        <>
          <JoinPage
            createRoomAction={sessionActions.createRoom}
            joinAction={sessionActions.join}
            onNewRoomCreated={(roomInfo) => setNewRoom(roomInfo)}
          />
          {newRoom && <div>{`New room created: ${JSON.stringify(newRoom)}`}</div>}
        </>
      ) : (
        <>
          <div className='meeting__participants-list' id='participants-list-root' />
          <div className='meeting__chat' id='chat-root' />
          {showParticipantsList &&
            ReactDOM.createPortal(
              <OnlineParticipantsList dismiss={() => setShowParticipantsList(false)} />,
              document.getElementById('participants-list-root')!
            )}
          {showChat &&
            ReactDOM.createPortal(
              <CombinedChat
                chatActions={chatActions}
                dismiss={() => setShowChat(false)}
                chatInputElement={ChatInputWithoutEmojiSelector}
              />,
              document.getElementById('chat-root')!
            )}
          <div className='room-controls'>
            <RoomControls mediaActions={localMediaActions} leaveAction={sessionActions.leave} />
          </div>
          <ViewSwitcher />
          <Participants speakerPageSize={4} />
          <div className='meeting__participants-list-button-container'>
            <button
              className='meeting__participants-list-button'
              disabled={showParticipantsList}
              onClick={() => setShowParticipantsList(true)}
            >
              Show Participants
            </button>
          </div>
          <div className='meeting__chat-button-container'>
            <button className='meeting__chat-button' disabled={showChat} onClick={() => setShowChat(true)}>
              Show Chat
            </button>
          </div>
        </>
      )}
    </div>
  )
}
